<?php

namespace EPIC\GALLERY;

use EPIC\GALLERY\Customizer\Options;

class Init {

	/**
	 * @var Init
	 */
	private static $instance;

	/**
	 * @return Init
	 */
	public static function getInstance() {
		if ( static::$instance === null ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Init constructor.
	 */
	private function __construct() {
		$this->load_helper();
		$this->setup_init();
		$this->setup_hook();

		epic_activation_hook( EPIC_GALLERY_FILE );
	}

	private function load_helper() {
		require_once EPIC_GALLERY_DIR . 'includes/helper.php';
	}

	private function setup_init() {
		Options::getInstance();
	}

	private function setup_hook() {
		add_action( 'wp_enqueue_scripts', [ $this, 'load_assets' ] );
		add_action( 'admin_enqueue_scripts', [ $this, 'load_admin_assets' ] );
		add_action( 'elementor/editor/after_enqueue_styles', [ $this, 'load_admin_assets' ] );

		// jeg-element integration
		add_filter( 'jeg_register_elements', [ $this, 'register_element' ] );
		add_filter( 'jeg_add_image_size', [ $this, 'register_image_size' ] );
		add_filter( 'jeg_show_default_module_customizer', '__return_false' );

		// wpbakery integration
		add_action( 'wp_enqueue_scripts', [ $this, 'wpbakery_frontend_assets' ] );
		add_action( 'admin_enqueue_scripts', [ $this, 'wpbakery_editor_assets' ], 99 );

		// elementor integration
		add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'elementor_frontend_assets' ] );

		// epic ad integration
		add_filter( 'epic_ad_register_placement', [ $this, 'epic_ad_register_placement' ] );
		add_filter( 'epic_ad_location_epic_gallery', [ $this, 'epic_ad_location_epic_gallery' ] );

		// Additional control for media library
		add_action( 'print_media_templates', [ $this, 'media_template' ] );

		add_action( 'plugins_loaded', [ $this, 'plugins_loaded' ] );
		add_filter( 'epic_plugin_list', [ $this, 'plugin_list' ] );

		/** photoswipe additional tag */
		add_action( 'wp_footer', [ $this, 'photoswipe_tag' ], 9 );

		/** Set attachment image size */
		add_filter( 'wp_get_attachment_image_attributes', [ $this, 'set_image_size' ], null, 2 );
	}

	/**
	 * Register ad placement
	 */
	public function epic_ad_register_placement( $value ) {
		$value[] = [
			'id'          => 'epic_gallery',
			'name'        => esc_html__( 'Epic Gallery Ad', 'epic-gallery' ),
			'description' => esc_html__( 'Custom ad placement for Epic Gallery.', 'epic-gallery' ),
		];

		return $value;
	}

	/**
	 * Register ad location
	 */
	public function epic_ad_location_epic_gallery( $value ) {
		$value[] = [
			'location'  => 'epic_gallery',
			'title'     => esc_html__( 'Epic Gallery Ad', 'epic-gallery' ),
			'thumbnail' => EPIC_GALLERY_URL . '/assets/img/admin/ad-placement.png',
		];

		return $value;
	}

	public function plugin_list( $plugins ) {
		$plugins[] = [
			'id'      => EPIC_GALLERY_ID,
			'name'    => EPIC_GALLERY_NAME,
			'slug'    => EPIC_GALLERY,
			'version' => EPIC_GALLERY_VERSION,
			'option'  => 'epic_gallery_license',
			'file'    => EPIC_GALLERY_FILE
		];

		return $plugins;
	}

	public function list_elements() {
		return [
			'Post_Gallery',
			'Image_Gallery'
		];
	}

	public function register_element( $elements ) {
		foreach ( $this->list_elements() as $item ) {
			$item_key              = 'eg_' . strtolower( $item );
			$namespace             = '\EPIC\GALLERY\Elements';
			$elements[ $item_key ] =
				[
					'option'    => $namespace . '\Options\\' . $item . '_Option',
					'view'      => $namespace . '\Views\\' . $item . '_View',
					'widget'    => $namespace . '\Widget\\' . $item . '_Widget',
					'elementor' => $namespace . '\Elementor\\' . $item . '_Elementor',
				];
		}

		return $elements;
	}

	/**
	 * Register all image size
	 *
	 * @param $sizes
	 *
	 * @return mixed
	 */
	public function register_image_size( $sizes ) {
		$sizes['120x86'] = [ 120, 86, true, 715 ];

		return $sizes;
	}

	public function plugins_loaded() {
		$this->alter_shortcode();
		$this->load_textdomain();
	}

	public function media_template() {
		$template = new Template( EPIC_GALLERY_TEMPLATE . 'media/' );
		$template->render( 'gallery-template', [ 'template' => $template ], true );
	}

	public function alter_shortcode() {
		remove_shortcode( 'gallery' );
		add_shortcode( 'gallery', [ $this, 'gallery_shortcode' ] );
	}

	public function photoswipe_tag() {
		if ( epic_gallery_popup_script() === 'photoswipe' ) {
			$html =
				'<div class="pswp" tabindex="-1" role="dialog" aria-hidden="true">
                <div class="pswp__bg"></div>
                <div class="pswp__scroll-wrap">
                    <div class="pswp__container">
                        <div class="pswp__item"></div>
                        <div class="pswp__item"></div>
                        <div class="pswp__item"></div>
                    </div>
                    <div class="pswp__ui pswp__ui--hidden">
                        <div class="pswp__top-bar">
                            <div class="pswp__counter"></div>
                            <button class="pswp__button pswp__button--close" title="' . jeg_return_translation( 'Close (Esc)', 'epic-gallery', 'close_esc' ) . '"></button>
                            <button class="pswp__button pswp__button--share" title="' . jeg_return_translation( 'Share', 'epic-gallery', 'share' ) . '"></button>
                            <button class="pswp__button pswp__button--fs" title="' . jeg_return_translation( 'Toggle fullscreen', 'epic-gallery', 'toggle_fullscreen' ) . '"></button>
                            <button class="pswp__button pswp__button--zoom" title="' . jeg_return_translation( 'Zoom in/out', 'epic-gallery', 'zoom_in_out' ) . '"></button>
                            <div class="pswp__preloader">
                                <div class="pswp__preloader__icn">
                                    <div class="pswp__preloader__cut">
                                        <div class="pswp__preloader__donut"></div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
                            <div class="pswp__share-tooltip"></div>
                        </div>
                        <button class="pswp__button pswp__button--arrow--left" title="' . jeg_return_translation( 'Previous (arrow left)', 'epic-gallery', 'previous_arrow_left' ) . '">
                        </button>
                        <button class="pswp__button pswp__button--arrow--right" title="' . jeg_return_translation( 'Next (arrow right)', 'epic-gallery', 'next_arrow_right' ) . '">
                        </button>
                        <div class="pswp__caption">
                            <div class="pswp__caption__center"></div>
                        </div>
                    </div>
                </div>
            </div>';

			echo apply_filters( 'epic_gallery_photoswipe_tag', $html );
		}
	}

	public function set_image_size( $attr, $attachment ) {
		if ( epic_gallery_popup_script() === 'photoswipe' ) {
			$image                    = wp_get_attachment_image_src( $attachment->ID, 'full' );
			$attr['data-full-width']  = $image[1];
			$attr['data-full-height'] = $image[2];
		}

		return $attr;
	}

	public function gallery_shortcode( $attr ) {
		$post = get_post();

		static $instance = 0;
		$instance ++;

		if ( ! empty( $attr['ids'] ) ) {
			// 'ids' is explicitly ordered, unless you specify otherwise.
			if ( empty( $attr['orderby'] ) ) {
				$attr['orderby'] = 'post__in';
			}
			$attr['include'] = $attr['ids'];
		}

		/**
		 * Filter the default gallery shortcode output.
		 *
		 * If the filtered output isn't empty, it will be used instead of generating
		 * the default gallery template.
		 *
		 * @param string $output The gallery output. Default empty.
		 * @param array $attr Attributes of the gallery shortcode.
		 *
		 * @since 2.5.0
		 *
		 * @see gallery_shortcode()
		 *
		 */
		$output = apply_filters( 'post_gallery', '', $attr );
		if ( $output != '' ) {
			return $output;
		}

		$html5 = current_theme_supports( 'html5', 'gallery' );
		$atts  = shortcode_atts( [
			'order'            => 'ASC',
			'orderby'          => 'menu_order ID',
			'id'               => $post ? $post->ID : 0,
			'itemtag'          => $html5 ? 'figure' : 'dl',
			'icontag'          => $html5 ? 'div' : 'dt',
			'captiontag'       => $html5 ? 'figcaption' : 'dd',
			'columns'          => 3,
			'size'             => 'thumbnail',
			'include'          => '',
			'exclude'          => '',
			'link'             => '',
			'epicslider'       => false,
			'epicslider_zoom'  => false,
			'epicslider_ads'   => false,
			'epicslider_title' => '&nbsp;',
		], $attr, 'gallery' );

		$zoom_script = apply_filters( 'epic_gallery_single_popup_script', 'disable' );

		if ( $zoom_script !== 'disable' ) {
			$atts['link'] = 'file';
		}

		$id = intval( $atts['id'] );

		if ( ! empty( $atts['include'] ) ) {
			$_attachments = get_posts( [
				'include'        => $atts['include'],
				'post_status'    => 'inherit',
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'order'          => $atts['order'],
				'orderby'        => $atts['orderby']
			] );

			$attachments = [];
			foreach ( $_attachments as $key => $val ) {
				$attachments[ $val->ID ] = $_attachments[ $key ];
			}
		} elseif ( ! empty( $atts['exclude'] ) ) {
			$attachments = get_children( [
				'post_parent'    => $id,
				'exclude'        => $atts['exclude'],
				'post_status'    => 'inherit',
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'order'          => $atts['order'],
				'orderby'        => $atts['orderby']
			] );
		} else {
			$attachments = get_children( [
				'post_parent'    => $id,
				'post_status'    => 'inherit',
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'order'          => $atts['order'],
				'orderby'        => $atts['orderby']
			] );
		}

		if ( empty( $attachments ) ) {
			return '';
		}

		if ( is_feed() ) {
			$output = "\n";
			foreach ( $attachments as $att_id => $attachment ) {
				$output .= wp_get_attachment_link( $att_id, $atts['size'], true ) . "\n";
			}

			return $output;
		}

		$itemtag    = tag_escape( $atts['itemtag'] );
		$captiontag = tag_escape( $atts['captiontag'] );
		$icontag    = tag_escape( $atts['icontag'] );
		$valid_tags = wp_kses_allowed_html( 'post' );
		if ( ! isset( $valid_tags[ $itemtag ] ) ) {
			$itemtag = 'dl';
		}
		if ( ! isset( $valid_tags[ $captiontag ] ) ) {
			$captiontag = 'dd';
		}
		if ( ! isset( $valid_tags[ $icontag ] ) ) {
			$icontag = 'dt';
		}

		$columns   = intval( $atts['columns'] );
		$itemwidth = $columns > 0 ? floor( 100 / $columns ) : 100;
		$float     = is_rtl() ? 'right' : 'left';

		$selector = "gallery_{$instance}";

		$gallery_style = '';

		if ( epic_gallery_is_enabled( $atts ) ) {

			$slider_size    = sizeof( $attachments );
			$image_slides   = $preview_description_content = '';
			$image_sequence = [];
			$sequence       = 0;

			foreach ( $attachments as $id => $attachment ) {
				$image_big    = wp_get_attachment_image_src( $attachment->ID, 'full' );
				$first_active = ( $sequence === 0 ) ? 'active' : '';

				$image_slides .=
					"<a data-id=\"{$sequence}\" data-title=\"{$attachment->post_excerpt}\" data-image=\"{$image_big[0]}\" href=\"{$image_big[0]}\" class=\"jeg_preview_item {$first_active}\">
                        <div class=\"jeg_preview_item_thumbnail\">
                            " . wp_get_attachment_image( $id, 'jeg-120x86' ) . "
                        </div>
                    </a>";

				$sequence ++;

				if ( epic_gallery_is_desc_enabled( $atts ) ) {
					$preview_description_content .=
						"<div class=\"jeg_hidden_preview_description\">
                            <h3>{$sequence}. {$attachment->post_excerpt}</h3>
                            <div class=\"jeg_preview_description_content\">
                                " . wpautop( $attachment->post_content ) . "
                            </div>
                        </div>";
				} else {
					$image_sequence[] = [
						'src'   => $image_big[0],
						'w'     => $image_big[1],
						'h'     => $image_big[2],
						'title' => $attachment->post_excerpt
					];
				}
			}

			$loader = epic_gallery_get_option( 'preview_slider_loader', 'dot' );

			$preview_holder_content =
				"<div class=\"jeg_preview_media\">
                    <div class=\"jeg_preview_media_holder\">
                        <h3>{$atts['epicslider_title']}</h3>
                        <div class=\"fullscreen-switch\">
                            <i class=\"fa\"></i>
                        </div>
                        <div class=\"jeg_preview_media_content\">
                            <div class=\"jeg_preview_media_content_holder_padding\">
                                <div class=\"jeg_preview_media_content_holder\"></div>
                            </div>
                            <div class=\"jeg_preview_media_content_navigation\">
                                <div class=\"prev\"></div>
                                <div class=\"next\"></div>
                            </div>
                            <div class='preview-slider-overlay'>
                                <div class='preloader_type preloader_{$loader}'>
                                    <div class=\"module-preloader jeg_preloader dot\">
                                        <span></span><span></span><span></span>
                                    </div>
                                    <div class=\"module-preloader jeg_preloader circle\">
                                        <div class=\"jeg_preloader_circle_outer\">
                                            <div class=\"jeg_preloader_circle_inner\"></div>
                                        </div>
                                    </div>
                                    <div class=\"module-preloader jeg_preloader square\">
                                        <div class=\"jeg-cube-grid\">
                                            <div class=\"jeg-cube jeg-cube1\"></div>
                                            <div class=\"jeg-cube jeg-cube2\"></div>
                                            <div class=\"jeg-cube jeg-cube3\"></div>
                                            <div class=\"jeg-cube jeg-cube4\"></div>
                                          </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class=\"jeg_preview_control\">
                            <div class=\"left_control\">
                                <div class=\"counter\"><span class=\"current\">1</span> " . jeg_return_translation( 'of', 'epic-gallery', 'of' ) . "  {$slider_size}</div>
                                <div class=\"subtitle\"></div>
                            </div>
                            <div class=\"zoom\">
                                <span class=\"reduce\">-</span>
                                <span class=\"increase\">+</span>
                            </div>
                        </div>
                    </div>
                </div>

                <div class=\"jeg_preview_bottom_slider owl-carousel\">
                    {$image_slides}
                </div>";

			$preview_ads_container = '';

			if ( epic_gallery_is_ads_enabled( $atts ) ) {
				$preview_ads_container =
					'<div class="jeg_preview_slider_ads">' . epic_gallery_ads() . '</div>';
			}

			// script parameter
			$is_rtl         = is_rtl() ? 'true' : 'false';
			$native_zoom    = epic_gallery_is_desc_enabled( $atts ) ? 'true' : 'false';
			$image_sequence = wp_json_encode( $image_sequence );
			$max_zoom       = apply_filters( 'epic_gallery_max_zoom', 5 );
			$zoom_step      = apply_filters( 'epic_gallery_zoom_step', 40 );
			$scheme         = epic_gallery_get_option( 'slider_scheme', 'dark' ) === 'light' ? 'slider_light' : '';

			$output =
				"<div class=\"jeg_preview_slider {$scheme} {$selector}\" data-selector='{$selector}'>
                    <div class=\"jeg_preview_holder\">
                        {$preview_holder_content}
                    </div>
                    <div class=\"jeg_preview_description\">
                        {$preview_ads_container}
                        <div class=\"jeg_preview_description_wrapper\">
                        {$preview_description_content}
                        </div>
                    </div>
                    <script>
                        var {$selector} = {
                            rtl: {$is_rtl},
                            native_zoom: {$native_zoom},
                            zoom_max: {$max_zoom},
                            zoom_step: {$zoom_step},
                            image_sequence: {$image_sequence}
                        };
                    </script>
                </div>";

		} else {

			/**
			 * Filter whether to print default gallery styles.
			 *
			 * @param bool $print Whether to print default gallery styles.
			 *                    Defaults to false if the theme supports HTML5 galleries.
			 *                    Otherwise, defaults to true.
			 *
			 * @since 3.1.0
			 *
			 */
			if ( apply_filters( 'use_default_gallery_style', ! $html5 ) ) {
				$gallery_style = "
                    <style type='text/css' scoped>
                        #{$selector} {
                            margin: auto;
                        }
                        #{$selector} .gallery-item {
                            float: {$float};
                            margin-top: 10px;
                            text-align: center;
                            width: {$itemwidth}%;
                        }
                        #{$selector} img {
                            border: 2px solid #cfcfcf;
                        }
                        #{$selector} .gallery-caption {
                            margin-left: 0;
                        }
                        /* see gallery_shortcode() in wp-includes/media.php */
                    </style>\n\t\t";
			}

			$size_class  = sanitize_html_class( $atts['size'] );
			$gallery_div = "<div id='$selector' class='gallery galleryid-{$id} gallery-columns-{$columns} gallery-size-{$size_class}'>";

			/**
			 * Filter the default gallery shortcode CSS styles.
			 *
			 * @param string $gallery_style Default CSS styles and opening HTML div container
			 *                              for the gallery shortcode output.
			 *
			 * @since 2.5.0
			 *
			 */
			$output = apply_filters( 'gallery_style', $gallery_style . $gallery_div );

			$i = 0;
			foreach ( $attachments as $id => $attachment ) {

				$attr = ( trim( $attachment->post_excerpt ) ) ? [ 'aria-describedby' => "$selector-$id" ] : '';
				if ( ! empty( $atts['link'] ) && $atts['link'] === 'file' ) {
					$image_output = wp_get_attachment_link( $id, $atts['size'], false, false, false, $attr );
				} elseif ( ! empty( $atts['link'] ) && $atts['link'] === 'none' ) {
					$image_output = wp_get_attachment_image( $id, $atts['size'], false, $attr );
				} else {
					$image_output = wp_get_attachment_link( $id, $atts['size'], true, false, false, $attr );
				}
				$image_meta = wp_get_attachment_metadata( $id );

				$orientation = '';
				if ( isset( $image_meta['height'], $image_meta['width'] ) ) {
					$orientation = ( $image_meta['height'] > $image_meta['width'] ) ? 'portrait' : 'landscape';
				}
				$output .= "<{$itemtag} class='gallery-item'>";
				$output .= "
            <{$icontag} class='gallery-icon {$orientation}'>
                $image_output
            </{$icontag}>";
				if ( $captiontag && trim( $attachment->post_excerpt ) ) {
					$output .= "
                <{$captiontag} class='wp-caption-text gallery-caption' id='$selector-$id'>
                " . wptexturize( $attachment->post_excerpt ) . "
                </{$captiontag}>";
				}
				$output .= "</{$itemtag}>";
				if ( $columns > 0 && ++ $i % $columns == 0 ) {
					$output .= '<br style="clear: both" />';
				}
			}

			if ( $columns > 0 && $i % $columns !== 0 ) {
				$output .= "
            <br style='clear: both' />";
			}

			$output .= "
        </div>\n";

		}

		return $output;
	}

	public function load_textdomain() {
		load_plugin_textdomain( EPIC_GALLERY, false, EPIC_GALLERY_DIR . '/languages/' );
	}

	/**
	 * Load frontend assets on the Elementor editor
	 */
	public function elementor_frontend_assets() {
		wp_enqueue_script( 'eg-elements-elementor', EPIC_GALLERY_URL . '/assets/js/admin/elementor-editor.js', [ 'jquery' ], EPIC_GALLERY_VERSION, false );
	}

	/**
	 * Load editor assets on the WPBakery editor
	 */
	public function wpbakery_frontend_assets() {
		if ( function_exists( 'vc_is_page_editable' ) && vc_is_page_editable() ) {
			wp_enqueue_script( 'eg-wpbakery-frontend', EPIC_GALLERY_URL . '/assets/js/admin/wpbakery-frontend.js', [ 'jquery' ], EPIC_GALLERY_VERSION, false );
		}
	}

	/**
	 * Load editor assets on the WPBakery editor
	 */
	public function wpbakery_editor_assets() {
		if ( function_exists( 'vc_is_frontend_editor' ) && vc_is_frontend_editor() ) {
			wp_enqueue_script( 'eg-wpbakery-editor', EPIC_GALLERY_URL . '/assets/js/admin/wpbakery-editor.js', [ 'jquery' ], EPIC_GALLERY_VERSION, false );
			wp_localize_script( 'eg-wpbakery-editor', 'egElements', $this->list_elements() );
		}
	}

	public function load_assets() {
		// Style
		wp_enqueue_style( 'jeg-icon', EPIC_GALLERY_URL . '/assets/fonts/jegicon/jegicon.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'font-awesome', JEG_URL . '/assets/font/font-awesome/font-awesome.css', null, jeg_get_version() );
		wp_enqueue_style( 'epic-gallery-main', EPIC_GALLERY_URL . '/assets/css/main.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'owl-carousel', EPIC_GALLERY_URL . '/assets/js/owl-carousel2/assets/owl.carousel.min.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'previewslider', EPIC_GALLERY_URL . '/assets/css/previewslider.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'previewslider-responsive', EPIC_GALLERY_URL . '/assets/css/previewslider-responsive.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'magnific-popup', EPIC_GALLERY_URL . '/assets/css/magnific-popup.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'photoswipe', EPIC_GALLERY_URL . '/assets/css/photoswipe/photoswipe.css', null, EPIC_GALLERY_VERSION );
		wp_enqueue_style( 'photoswipe-default', EPIC_GALLERY_URL . '/assets/css/photoswipe/default-skin/default-skin.css', null, EPIC_GALLERY_VERSION );

		if ( is_rtl() ) {
			wp_enqueue_style( 'previewslider-rtl', EPIC_GALLERY_URL . '/assets/css/previewslider-rtl.css', null, EPIC_GALLERY_VERSION );
		}

		// Script
		if ( epic_gallery_get_option( 'single_popup_script', 'magnific' ) === 'photoswipe' ) {
			wp_enqueue_script( 'photoswipe', EPIC_GALLERY_URL . '/assets/js/photoswipe/photoswipe.js', null, EPIC_GALLERY_VERSION, true );
			wp_enqueue_script( 'photoswipe-ui-default', EPIC_GALLERY_URL . '/assets/js/photoswipe/photoswipe-ui-default.js', null, EPIC_GALLERY_VERSION, true );
		}
		wp_enqueue_script( 'owl-carousel', EPIC_GALLERY_URL . '/assets/js/owl-carousel2/owl.carousel.js', null, EPIC_GALLERY_VERSION, true );
		wp_enqueue_script( 'magnific', EPIC_GALLERY_URL . '/assets/js/jquery.magnific-popup.js', null, EPIC_GALLERY_VERSION, true );
		wp_enqueue_script( 'previewslider', EPIC_GALLERY_URL . '/assets/js/jquery.previewslider.js', [ 'jquery' ], EPIC_GALLERY_VERSION );
		wp_enqueue_script( 'epic-galery-main', EPIC_GALLERY_URL . '/assets/js/main.js', null, EPIC_GALLERY_VERSION, true );
		wp_localize_script( 'epic-galery-main', 'epic_gallery_option', $this->localize_script() );
	}

	public function load_admin_assets() {
		wp_enqueue_style( 'epic-gallery-admin-style', EPIC_GALLERY_URL . '/assets/css/admin/admin-style.css', null, EPIC_GALLERY_VERSION );
	}

	public function localize_script() {
		$option                   = [];
		$option['popup_script']   = epic_gallery_get_option( 'single_popup_script', 'magnific' );
		$option['single_gallery'] = epic_gallery_get_option( 'single_as_gallery', false );
		$option['rtl']            = is_rtl() ? 1 : 0;

		return apply_filters( 'epic_gallery_asset_localize_script', $option );
	}


}